==> v1.0.0.20171026_beta.tar.gz: fastadmin/application/admin/lang/zh-cn/addon.php <==
<?php

return [
    'Id'                             => 'ID',
    'Title'                          => '标题',
    'Value'                          => '配置值',
    'Array key'                      => '键',
    'Array value'                    => '值',
    'File'                           => '文件',
    'Donate'                         => '打赏作者',
    'Warmtips'                       => '温馨提示',
    'Offline install'                => '离线安装',
    'Refresh addon cache'            => '刷新插件缓存',
    'Userinfo'                       => '会员信息',
    'Online store'                   => '在线商店',
    'Local addon'                    => '本地插件',
    'Https tips'                     => '当前你无法在插件管理中在线安装FastAdmin市场中的插件，请前往 <a href="http://www.fastadmin.net/store.html" target="_blank" class="">FastAdmin插件市场</a> 中下载后进行离线安装。',
    'Conflict tips'                  => '此插件中发现和现有系统中部分文件发现冲突！以下文件将会被影响，请备份好相关文件后再继续操作',
    'Login tips'                     => '此处登录账号为<a href="http://www.fastadmin.net" target="_blank">FastAdmin官网账号</a>',
    'Logined tips'                   => '你好！%s<br />当前你已经登录，将同步保存你的购买记录',
    'Pay tips'                       => '支付完成后请稍等1~5分钟后再尝试安装，请不要重复支付，如果仍然无法安装，请加<a href="https://jq.qq.com/?_wv=1027&k=487PNBb" target="_blank">QQ群：636393962</a>向管理员反馈',
    'Pay click tips'                 => '请点击这里在新窗口中进行支付！',
    'Pay new window tips'            => '请在新弹出的窗口中进行支付，支付完成后再重新点击安装按钮进行安装！',
    'Uninstall tips'                 => '确认卸载插件？<p class="text-danger">卸载将会删除所有插件文件且不可找回!!! 插件如果有创建数据库表请手动删除!!!</p>如有重要数据请备份后再操作！',
    'Offline installed tips'         => '插件安装成功！你需要手动启用该插件，并清除缓存使之生效',
    'Online installed tips'          => '插件安装成功！清除插件缓存和框架缓存后生效！',
    'Not login tips'                 => '你当前未登录FastAdmin，登录后将同步已购买的记录，下载时无需二次付费！',
    'Login now'                      => '立即登录',
    'Continue install'               => '不登录,继续安装',
    'Recommend'                      => '推荐',
    'Hot'                            => '热门',
    'New'                            => '新',
    'Free'                           => '免费',
    'Sale'                           => '折扣',
    'No image'                       => '暂无缩略图',
    'Author'                         => '作者',
    'Intro'                          => '介绍',
    'Version'                        => '版本',
    'Createtime'                     => '添加时间',
    'Demo'                           => '在线演示',
    'Install'                        => '安装',
    'Uninstall'                      => '卸载',
    'Setting'                        => '配置',
    'Disable'                        => '禁用',
    'Enable'                         => '启用',
    'Your username or email'         => '你的用户名或邮箱',
    'Your password'                  => '你的密码',
    'Login FastAdmin'                => '登录FastAdmin',
    'Login'                          => '登录',
    'Logout'                         => '退出登录',
    'Register'                       => '注册账号',
    'You\'re not login'              => '当前未登录',
    'Pay now'                        => '立即支付',
    'Continue install'               => '继续安装',
    'Continue uninstall'             => '继续安装',
    'Continue operate'               => '继续操作',
    'Install successful'             => '安装成功',
    'Uninstall successful'           => '卸载成功',
    'Operate successful'             => '操作成功',
    'Addon info file was not found'  => '插件配置文件未找到',
    'Addon info file data incorrect' => '插件配置文件未找到',
    'Addon info file data incorrect' => '插件配置信息不正确',
    'Addon already exists'           => '上传的插件已经存在',
];

==> v1.0.0.20180314_beta.tar.gz: fastadmin/application/admin/lang/zh-cn/addon.php <==
<?php

return [
    'Id'                             => 'ID',
    'Title'                          => '标题',
    'Value'                          => '配置值',
    'Array key'                      => '键',
    'Array value'                    => '值',
    'File'                           => '文件',
    'Donate'                         => '打赏作者',
    'Warmtips'                       => '温馨提示',
    'Offline install'                => '离线安装',
    'Refresh addon cache'            => '刷新插件缓存',
    'Userinfo'                       => '会员信息',
    'Online store'                   => '在线商店',
    'Local addon'                    => '本地插件',
    'Https tips'                     => '当前你无法在插件管理中在线安装FastAdmin市场中的插件，请前往 <a href="http://www.fastadmin.net/store.html" target="_blank" class="">FastAdmin插件市场</a> 中下载后进行离线安装。',
    'Conflict tips'                  => '此插件中发现和现有系统中部分文件发现冲突！以下文件将会被影响，请备份好相关文件后再继续操作',
    'Login tips'                     => '此处登录账号为<a href="http://www.fastadmin.net" target="_blank">FastAdmin官网账号</a>',
    'Logined tips'                   => '你好！%s<br />当前你已经登录，将同步保存你的购买记录',
    'Pay tips'                       => '支付完成后请稍等1~5分钟后再尝试安装，请不要重复支付，如果仍然无法安装，请加<a href="https://jq.qq.com/?_wv=1027&k=487PNBb" target="_blank">QQ群：636393962</a>向管理员反馈',
    'Pay click tips'                 => '请点击这里在新窗口中进行支付！',
    'Pay new window tips'            => '请在新弹出的窗口中进行支付，支付完成后再重新点击安装按钮进行安装！',
    'Uninstall tips'                 => '确认卸载插件？<p class="text-danger">卸载将会删除所有插件文件且不可找回!!! 插件如果有创建数据库表请手动删除!!!</p>如有重要数据请备份后再操作！',
    'Upgrade tips'                   => '确认升级插件？<p class="text-danger">如果之前购买插件时未登录，此次升级可能出现购买后才可以下载的提示!!!<br>升级后可能出现部分冗余数据记录,请根据需要移除即可!!!</p>如有重要数据请备份后再操作！',
    'Offline installed tips'         => '插件安装成功！清除插件缓存和框架缓存后生效！',
    'Online installed tips'          => '插件安装成功！清除插件缓存和框架缓存后生效！',
    'Not login tips'                 => '你当前未登录FastAdmin，登录后将同步已购买的记录，下载时无需二次付费！',
    'Not installed tips'             => '请安装后再访问插件前台页面！',
    'Not enabled tips'               => '插件已经禁用,请启用后再访问插件前台页面！',
    'Please disable addon first'     => '请先禁用插件再进行升级',
    'Login now'                      => '立即登录',
    'Continue install'               => '不登录,继续安装',
    'Recommend'                      => '推荐',
    'Hot'                            => '热门',
    'New'                            => '新',
    'Free'                           => '免费',
    'Sale'                           => '折扣',
    'No image'                       => '暂无缩略图',
    'Price'                          => '价格',
    'Author'                         => '作者',
    'Identify'                       => '标识',
    'Homepage'                       => '主页',
    'Intro'                          => '介绍',
    'Version'                        => '版本',
    'Createtime'                     => '添加时间',
    'Releasetime'                    => '更新时间',
    'Detail'                         => '插件详情',
    'Document'                       => '文档',
    'Demo'                           => '在线演示',
    'Feedback'                       => '反馈BUG',
    'Install'                        => '安装',
    'Uninstall'                      => '卸载',
    'Upgrade'                        => '升级',
    'Setting'                        => '配置',
    'Disable'                        => '禁用',
    'Enable'                         => '启用',
    'Your username or email'         => '你的用户名或邮箱',
    'Your password'                  => '你的密码',
    'Login FastAdmin'                => '登录FastAdmin',
    'Login'                          => '登录',
    'Logout'                         => '退出登录',
    'Register'                       => '注册账号',
    'You\'re not login'              => '当前未登录',
    'Pay now'                        => '立即支付',
    'Continue install'               => '继续安装',
    'Continue uninstall'             => '继续安装',
    'Continue operate'               => '继续操作',
    'Install successful'             => '安装成功',
    'Uninstall successful'           => '卸载成功',
    'Operate successful'             => '操作成功',
    'Addon info file was not found'  => '插件配置文件未找到',
    'Addon info file data incorrect' => '插件配置信息不正确',
    'Addon already exists'           => '上传的插件已经存在',
];
